@@ -113,9 +113,9 @@ od.3m <- function(n = NULL, J = NULL, p = NULL, icc2 = NULL, icc3 = NULL,
                  Klim = c(6, 1e10), q = 1, d = 0.1,
                  vartitle = NULL,verbose = TRUE, iter = 100, tol = 1e-10,
                  power = 0.8, ACO = TRUE,
-                 d.p = c(0.5, 0.9), d.n = c(2, 1000), d.J = c(2, 1000),
+                 d.p = c(0.5, 0.9), d.n = c(2, 100), d.J = c(2, 100),
                  sig.level = 0.05, two.tailed = TRUE,
-                 nrange = c(2, 10000), Jrange = c(2, 10000),
+                 nrange = c(2, 1000), Jrange = c(2, 1000),
                  max.value = Inf, max.iter = 300,  e = 1e-10,
                  n.of.ants = 10, n.of.archive = 50, q.aco = 0.0001,
                  xi = 0.5) {
@@ -142,14 +142,14 @@ od.3m <- function(n = NULL, J = NULL, p = NULL, icc2 = NULL, icc3 = NULL,
               c1 = c1, c2 = c2, c3 = c3,
               c1t =c1t, c2t = c2t,  omega = omega,
               n = n, J = J, p = p, iter = iter,
-              tol = 1e-10,
-              power = 0.8, ACO = TRUE,
-              d.p = c(0.5, 0.9), d.n = c(2, 1000), d.J = c(2, 1000),
-              sig.level = 0.05, two.tailed = TRUE,
-              nrange = c(2, 10000), Jrange = c(2, 10000),
-              max.value = Inf, max.iter = 300,  e = 1e-10,
-              n.of.ants = 10, n.of.archive = 50, q.aco = 0.0001,
-              xi = 0.5)
+              tol = tol,
+              power = power, ACO = ACO,
+              d.p = d.p, d.n = d.n, d.J = d.J,
+              sig.level = sig.level, two.tailed = two.tailed,
+              nrange = nrange, Jrange = Jrange,
+              max.value = max.value, max.iter = max.iter,  e = e,
+              n.of.ants = n.of.ants, n.of.archive = n.of.archive, q.aco = q.aco,
+              xi = xi)
   if(ACO){ # if ACO == TRUE
     tside <- ifelse(two.tailed == TRUE, 2, 1)
     if (two.tailed == TRUE) {
